<?php declare(strict_types=1);
/**
 * JTL Plugin
 * Copyright (C) 2011 - 2020 Andreas Petermann
 *
 * PHP version 7.2+
 *
 * @copyright css-umsetzung
 * @author Andreas Petermann <info@css-umsetzung.de>
 * @package css_gutschein
 * @license GNU
 * @version 2.0.1
 *
 */

namespace Plugin\css_gutschein;

use JTL\Catalog\Product\Preise;
use JTL\Alert\Alert;
use JTL\Catalog\Category\Kategorie;
use JTL\Catalog\Product\Artikel;
use JTL\Events\Dispatcher;
use JTL\Events\Event;
use JTL\Helpers\Form;
use JTL\Helpers\Request;
use JTL\Link\LinkInterface;
use JTL\Plugin\Bootstrapper;
use JTL\Shop;
use JTL\Smarty\JTLSmarty;
use JTL\Session\Frontend;

use Plugin\css_gutschein\src\cssPlugin;
/**
 * Class Bootstrap
 * @package Plugin\jtl_test
 */

define("CSS_GUTSCHEIN_PRIO",101);


class Bootstrap extends Bootstrapper
{
    /**
     * @var TestHelper
     */
    private $cssPlugin;

    /**
     * @inheritdoc
     */
    public function boot(Dispatcher $dispatcher)
    {

        parent::boot($dispatcher);
            $plugin = $this->getPlugin();

        if (Shop::isFrontend() === true || (isset($_REQUEST['kPlugin']) &&  $plugin->getID() == (int) $_REQUEST['kPlugin'])) {

            $this->cssPlugin = src\cssPlugin\cssPlugin::getInstance(
                $plugin,
                $this->getDB(),
                $this->getCache()
            );
        }
        if (Shop::isFrontend() === true) {
            $cfg = $this->cssPlugin->getConfig();
            if($cfg->pluginActive=='N') return;

#	        $dispatcher->listen('shop.hook.' . \HOOK_SETZTE_POSITIONSPREISE, function (array $args) use ($plugin) {
#		        $this->cssPlugin->hookSetztePositionspreise($args);
#	        },CSS_GUTSCHEIN_PRIO);

	        $dispatcher->listen('shop.hook.' . \HOOK_ARTIKEL_PAGE, function (array $args) use ($plugin) {
		        $this->cssPlugin->hookArtikelPage($args);
	        });

	        $dispatcher->listen('shop.hook.' . \HOOK_KUNDE_CLASS_LOADFROMDB   , function (array $args) use ($plugin) {
		        $this->cssPlugin->hookJtlPageMeinkkonto ($args);
	        },CSS_GUTSCHEIN_PRIO);


          $dispatcher->listen('shop.hook.' . \HOOK_SMARTY_OUTPUTFILTER, function () use ($plugin) {
	          $this->cssPlugin->hookSmartyOutputfilter();
          },CSS_GUTSCHEIN_PRIO);

	        $dispatcher->listen('shop.hook.' . \HOOK_IO_HANDLE_REQUEST, function (array $args) use ($plugin) {

		        $this->cssPlugin->hookIoHandleRequest($args);
	        },CSS_GUTSCHEIN_PRIO);

	        $dispatcher->listen('shop.hook.' . \HOOK_CSS_JS_LIST, function (array $args) use ($plugin) {
		        $this->cssPlugin->hookCssJsList($args);
	        },CSS_GUTSCHEIN_PRIO);

	        $dispatcher->listen('shop.hook.' . \HOOK_LASTJOBS_HOLEJOBS, function () use ($plugin) {
		        $this->cssPlugin->hookLastjobsHolejobs();
	        });


#	        $dispatcher->listen('shop.hook.' . \HOOK_TOOLSGLOBAL_INC_SETZESPRACHEUNDWAEHRUNG_WAEHRUNG , function () use ($plugin) {
#		        $this->cssPlugin->hookToolsglobalIncSetzespracheundwaehrungWaehrung();
#	        },CSS_GUTSCHEIN_PRIO);


	        $dispatcher->listen('shop.hook.' . \HOOK_BESTELLABSCHLUSS_INC_BESTELLUNGINDB_ENDE, function (array $args) use ($plugin) {
                $this->cssPlugin->hookBestellabschlussIncBestellungindbEnde($args);
            },CSS_GUTSCHEIN_PRIO);

	        $dispatcher->listen('shop.hook.' . \HOOK_BESTELLABSCHLUSS_INC_BESTELLUNGINDB, function (array $args) use ($plugin) {
                $this->cssPlugin->hookBestellabschlussIncBestellungindb($args);
            },CSS_GUTSCHEIN_PRIO);


	        $dispatcher->listen('shop.hook.' . \HOOK_BESTELLABSCHLUSS_PAGE, function (array $args) use ($plugin) {
                $this->cssPlugin->hookLetzterincludeInc($args);
            },CSS_GUTSCHEIN_PRIO);

	        $dispatcher->listen('shop.hook.' . \HOOK_NOTIFY_HASHPARAMETER_DEFINITION, function (array $args) use ($plugin) {
                $this->cssPlugin->hookLetzterincludeInc($args);
            },CSS_GUTSCHEIN_PRIO);

	        $dispatcher->listen('shop.hook.' . \HOOK_LETZTERINCLUDE_INC, function (array $args) use ($plugin) {
                $this->cssPlugin->hookLetzterincludeInc($args);
            },CSS_GUTSCHEIN_PRIO);

        }  else {

#            require_once $plugin->getPaths()->getBasePath() . 'includes/defines_inc.php';
#            $this->admin = new Admin($this->getDB(), Shop::Container()->getBackendLogService());
        }

    }        

    /**
     * @inheritdoc
     */
    public function installed()
    {
#        $minify          = new MinifyService();
#        $minify->flushCache();
	      $plugin  = $this->getPlugin();
		    $obj = new \stdClass();
		    $obj->cAktiv = 'Y';
		    $obj->nFehlerhaft = '0';
		    $this->getDB()->update('temailvorlage','kPlugin',$plugin->getID(),$obj);
        Shop::Cache()->flushTags(array(CACHING_GROUP_TEMPLATE,CACHING_GROUP_PLUGIN,'cache_'.$plugin->getPluginID()));
        parent::installed();
    }

    /**
     * @inheritdoc
     */
    public function updated($oldVersion, $newVersion)
    {
        $plugin  = $this->getPlugin();
#        $minify          = new MinifyService();
#        $minify->flushCache();
        Shop::Cache()->flushTags(array(CACHING_GROUP_TEMPLATE,CACHING_GROUP_PLUGIN,'cache_'.$plugin->getPluginID()));
        \error_log('updated from ' . $oldVersion . ' to ' . $newVersion);
    }

    /**
     * @inheritdoc
     */
    public function uninstalled(bool $deleteData = true)
    {
        if($deleteData === true) {
#            $this->getDB()->query('DROP TABLE IF EXISTS `css_gutscheinConfig`', 3);
// DROP TABLE IF EXISTS `css_gutscheinBasketCard`, `css_gutscheinConfig`, `css_gutscheinCupon`, `css_gutscheinFolderLang`, `css_gutscheinFolders`, `css_gutscheinHistory`, `css_gutscheinImage`, `css_gutscheinImageToLang`, `css_gutscheinOrder`;

        }
        parent::uninstalled($deleteData);
        $plugin  = $this->getPlugin();
#        $minify          = new MinifyService();
#        $minify->flushCache();
        Shop::Cache()->flushTags(array(CACHING_GROUP_TEMPLATE,CACHING_GROUP_PLUGIN,'cache_'.$plugin->getPluginID()));
    }
}
